@@ -1117,14 +1117,14 @@ class Module(object):
                     # contains qweb file
                     is_web = True
                     if local_path.suffix == '.xml':
-                        if mod.get('qweb'):
+                        if 'qweb' in mod:
                             mod['qweb'].append(str(local_path))
                 else:
                     mod[DATA_NAME].append(str(local_path))
             elif local_path.suffix == '.js':
                 pass
             elif local_path.suffix in ['.css', '.less', '.scss']:
-                if mod.get('css'):
+                if 'css' in mod:
                     mod["css"].append(str(local_path))
 
         # keep test empty: use concrete call to test-file instead of testing on every module update
